@@ -1,10 +1,11 @@
 <?php
+#BEGIN_LICENSE
 #-------------------------------------------------------------------------
 # Module: CGGoogleMaps - A simple module for creating google maps.
 # Version: 1.0, calguy1000 <calguy1000@hotmail.com>
 #
 #-------------------------------------------------------------------------
-# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
+# CMS - CMS Made Simple is (c) 2004-2012 by Ted Kulp (wishy@cmsmadesimple.org)
 # This project's homepage is: http://www.cmsmadesimple.org
 # The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
 #
@@ -15,6 +16,12 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
+# However, as a special exception to the GPL, this software is distributed
+# as an addon module to CMS Made Simple.  You may not use this software
+# in any Non GPL version of CMS Made simple, or in any version of CMS
+# Made simple that does not indicate clearly and obviously in its admin 
+# section that the site was built with CMS Made simple.
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -25,7 +32,7 @@
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
 #
 #-------------------------------------------------------------------------
-
+#END_LICENSE
 
 $cgextensions = cms_join_path($gCms->config['root_path'],'modules',
 			      'CGExtensions','CGExtensions.module.php');
@@ -110,74 +117,71 @@ function cggm_add_dynpoint($params, &$smarty)
   $mod = cge_utils::get_module('CGGoogleMaps');
   if( !$mod ) return;
   $map = '';
-  if( isset($params['map']) )
-    {
-      $map = $params['map'];
-    }
-  else
-    {
-      $map = $mod->GetPreference('default_map',0);
-    }
+  if( isset($params['map']) ) {
+    $map = $params['map'];
+  }
+  else {
+    $map = $mod->GetPreference('default_map',0);
+  }
   
-  if( !is_numeric($map) )
-    {
-      $mapobj = cggm_map_operations::load_by_name($map);
-      $map = $mapobj->id;
-    }
+  if( !is_numeric($map) ) {
+    $mapobj = cggm_map_operations::load_by_name($map);
+    $map = $mapobj->id;
+  }
 
-  if( !isset($params['name']) )
-    {
-      // name is required
-      return; 
-    }
+  if( !isset($params['name']) ) {
+    // name is required
+    return; 
+  }
   $name = $params['name'];
+  if( $name == '' ) return;
 
   $description = '';
-  if( isset($params['desc']) )
-    {
-      $description = $params['desc'];
-    }
-  if( isset($params['description']) )
-    {
-      $description = $params['description'];
-    }
+  if( isset($params['desc'])  && $params['desc'] != '' ) {
+    $description = $params['desc'];
+  }
+  else if( isset($params['description']) && $params['description'] != '' ) {
+    $description = $params['description'];
+  }
   
   $address = '';
-  if( isset($params['address']) )
-    {
-      $address = $params['address'];
-    }
+  if( isset($params['address']) && $params['address'] != '' ) {
+    $address = $params['address'];
+  }
   
   $lat = '';
-  if( isset($params['lat']) )
-    {
-      $lat = $params['lat'];
-    }
+  if( isset($params['lat']) && $params['lat'] != '' ) {
+    $lat = $params['lat'];
+  }
+  else if( isset($params['latitude']) && $params['latitude'] != '' ) {
+    $lat = $params['latitude'];
+  }
   
   $long = '';
-  if( isset($params['long']) )
-    {
-      $long = $params['long'];
-    }
+  if( isset($params['long']) && $params['long'] |= '' ) {
+    $long = $params['long'];
+  }
+  else if( isset($params['longitude']) && $params['longitude'] |= '' ) {
+    $long = $params['longitude'];
+  }
 
   $icon = '';
-  if( isset($params['icon']) )
-    {
-      $icon = $params['icon'];
-    }
+  if( isset($params['icon']) && $params['icon'] != '') {
+    $icon = $params['icon'];
+  }
 
   $obj = new cggm_marker($name,$address,$lat,$long,$icon);
   $obj->set_description($description);
-  if( isset($params['category']) )
-    {
-      $tmp = trim($params['category']);
-      if( $tmp )
-	{
-	  $obj->add_category(trim($tmp));
-	}
+  if( isset($params['category']) && $params['category'] != '' ) {
+    $tmp = trim($params['category']);
+    if( $tmp ) {
+      $obj->add_category(trim($tmp));
     }
+  }
 
-  if( isset($params['tooltip']) )  $obj->set_tooltip($params['tooltip']);
+  if( isset($params['tooltip']) && $params['tooltip'] != '' ) {
+    $obj->set_tooltip($params['tooltip']);
+  }
   $mod->add_map_point($map,$obj);
 }
 
@@ -224,7 +228,7 @@ class CGGoogleMaps extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '2.2.7';
+    return '2.2.9';
   }
 
 
@@ -369,6 +373,8 @@ EOT;
 
     $this->CreateParameter('zoom_encompass','',$this->Lang('help_param_zoomencompass'));
     $this->SetParameterType('zoom_encompass',CLEAN_INT);
+
+    $this->SetParameterType('address',CLEAN_STRING);
   }
 
 
