@@ -34,7 +34,6 @@ $defer = 0;
 $mapid = '';
 $map = '';
 $icons = '';
-$apikey = '';
 
 //
 // setup
@@ -43,7 +42,6 @@ if( isset($params['defer']) && $params['defer'] == 1 )
   {
     $defer = 1;
   }
-$apikey = $this->GetPreference('google_apikey','');
 
 //
 // Get the map information
@@ -82,8 +80,21 @@ if( is_array($this->_dynamic_points) && isset($this->_dynamic_points[$mid]) && c
 	$map->add_marker($this->_dynamic_points[$mid][$i]);
       }
   }
+$this->_dynamic_points = null;
 
-$generator = new cggm_map_generator($map,$apikey,$defer);
+// add more parameters
+if( isset($params['zoomlevel']) )
+  {
+    $val = min((int)$params['zoomlevel'],17);
+    $val = max(1,$val);
+    $map->zoom = $val;
+  }
+if( isset($params['zoom_encompass']) )
+  {
+    $map->zoom_encompass = ((int)$params['zoom_encompass']);
+  }
+
+$generator = new cggm_map_generator($map,$defer);
 $output = $generator->generate();
 $errors = $generator->get_errors();
 if( is_array($errors) )
