@@ -35,9 +35,6 @@ if( !$this->CheckPermission('Modify Site Preferences') )
 $smarty->assign('formstart',
 		$this->CGCreateFormStart($id,'admin_saveprefs',$returnid));
 $smarty->assign('formend',$this->CreateFormEnd());
-$smarty->assign('prompt_apikey',$this->Lang('google_api_key'));
-$smarty->assign('input_apikey',$this->CreateInputText($id,'google_apikey',
-						      $this->GetPreference('google_apikey',''),100,1024));
 $smarty->assign('submit',$this->CreateInputSubmit($id,'submit',$this->Lang('submit')));
 $smarty->assign('lookup_services',array('GOOGLE'=>'Google','YAHOO'=>'Yahoo'));
 $smarty->assign('lookup_service',$this->GetPreference('lookup_service','GOOGLE'));
