@@ -116,8 +116,8 @@ $lang['help'] = <<<EOT
 <li><strong>required</strong> - name : The name of the point to add</li>
 <li><em>optional</em> - desc/description : The HTML content to show in the info window</li>
 <li><em>optional</em> - address : The address of the location you are adding. (you must specify an address, or lat and long parameters)</li>
-<li><em>optional</em> - lat : The latitude of the location you are adding.</li>
-<li><em>optional</em> - long : The longitude of the location you are adding.</li>
+<li><em>optional</em> - lat/latitude : The latitude of the location you are adding.</li>
+<li><em>optional</em> - long/longitude : The longitude of the location you are adding.</li>
 <li><em>optional</em> - category : A comma separated list of categories for this point (there is no need for the categories to already exists)</li>
 <li><em>optional</em> - tooltip : A tooltip to display when hovering over a point.</li>
 <li><em>optional</em> - icon : The name of an icon to use for this point.</li>
