@@ -11,42 +11,42 @@ $lang['anchor_y'] = 'Anker Y Pixel Ort';
 $lang['apply'] = 'Best&auml;tigen';
 $lang['ask_delete_icon'] = 'Wollen Sie wirklich dieses Icon aus der Liste entfernen (es werden keine Dateien gel&ouml;scht)?';
 $lang['ask_reset_icons'] = 'Wollen Sie wirklich alle Icons entfernen und auf die programmseitigen Voreinstellungen zur&uuml;cksetzen?';
-$lang['baloon_maptemplate'] = 'Ballon Template';
+$lang['baloon_maptemplate'] = 'Ballon-Template';
 $lang['cancel'] = 'Abbrechen';
 $lang['category_template'] = 'Kategorie-Template';
 $lang['center_lat'] = 'Mitte Breitengrad';
 $lang['center_lon'] = 'Mitte L&auml;ngengrad';
-$lang['clearcache'] = 'Geolocate Cache leeren';
+$lang['clearcache'] = 'Geolocate-Cache leeren';
 $lang['click'] = 'Klicken';
-$lang['combine_points'] = 'Kombinieren einzelner Marker innerhalb der Reichweite';
+$lang['combine_points'] = 'Einzelner Marker innerhalb der Reichweite kombinieren';
 $lang['combined_points_icon'] = 'Icon f&uuml;r kombinierte Nutzung';
 $lang['controls'] = 'Bedienelemente';
 $lang['controls_size'] = 'Gr&ouml;&szlig;e der Bedienelemente';
 $lang['default'] = 'Standard';
-$lang['default_icon'] = 'Standard Icon';
+$lang['default_icon'] = 'Standard-Icon';
 $lang['default_templates'] = 'Standard-Templates';
 $lang['delete'] = 'L&ouml;schen';
 $lang['delete_icon'] = 'Dieses Icon l&ouml;schen';
 $lang['delete_map'] = 'Karte l&ouml;schen';
 $lang['delete_map_point'] = 'Kartenpunkt l&ouml;schen';
 $lang['description'] = 'Beschreibung';
-$lang['directions'] = 'Bedienungsanleitung anzeigen';
+$lang['directions'] = 'Richtungen anzeigen';
 $lang['directions_dest'] = 'Wo sollten Richtungen gezeichnet werden';
 $lang['directions_units'] = 'Richtungs Einheiten';
-$lang['dirform_maptemplate'] = 'Richtungs Formularvorlage';
-$lang['dropdown'] = 'Dropdown';
+$lang['dirform_maptemplate'] = 'Richtungs-Formular-Template';
+$lang['dropdown'] = 'Listenfeldmen&uuml;';
 $lang['edit'] = 'Bearbeiten';
-$lang['edit_category'] = 'Marker Kategorie bearbieten';
+$lang['edit_category'] = 'Marker-Kategorie bearbeiten';
 $lang['edit_icon'] = 'Dieses Icon bearbeiten';
 $lang['edit_map'] = 'Karte bearbeiten';
 $lang['edit_map_point'] = 'Kartenpunkt bearbeiten';
 $lang['edit_map_points'] = 'Kartenpunkte bearbeiten';
 $lang['edit_points_for_map'] = 'Kartenpunkte f&uuml;r die Karte %s bearbeiten';
-$lang['error_browser_incompatible'] = 'Dieser Browser kann, Google Maps nicht anzeigen';
+$lang['error_browser_incompatible'] = 'Dieser Browser kann Google Maps nicht anzeigen';
 $lang['error_cannotdelete'] = 'Dieser Eintrag konnte nicht entfernt werden';
 $lang['error_deletecategory'] = 'Problem beim L&ouml;schen der Kategorie';
 $lang['error_invalidparams'] = 'Ein oder mehrere Parameter sind entweder nicht vorhanden oder falsch.';
-$lang['error_mapelem_notfound'] = 'Karten Element wurde nicht gefunden';
+$lang['error_mapelem_notfound'] = 'Karten-Element wurde nicht gefunden';
 $lang['error_nameexists'] = 'Ein Element mit diesem Namen existiert bereits';
 $lang['error_noapikey'] = 'Der Google-API-Key ist leer';
 $lang['error_noapikey2'] = 'Der Google-API-Key ist leer. Solange dieser nicht mit einem g&uuml;ltigen Wert (so wie von Google angegeben) hinterlegt wurde, wird dieses Modul nicht richtig funktionieren.';
@@ -136,41 +136,41 @@ $lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable
 $lang['info_sidebar'] = 'Should a sidebar containing all map points be displayed?';
 $lang['info_sv_controls'] = 'Soll das Bedienelement f&uuml;r StreetView auf der Karte angezegit werden?';
 $lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street.';
-$lang['info_sysdflt_baloon_template'] = 'Standard &quot;Ballon&quot; Template';
-$lang['info_sysdflt_category_template'] = 'Standard &quot;Kategorie&quot; Listen-Template';
-$lang['info_sysdflt_dirform_template'] = 'Standard &quot;Richtungs-Formular&quot; Template';
-$lang['info_sysdflt_js_template'] = 'Standard Javascript Template';
-$lang['info_sysdflt_map_template'] = 'Standard Karten template';
-$lang['info_sysdflt_sidebar_template'] = 'Standard Seitenleisten Template';
+$lang['info_sysdflt_baloon_template'] = 'Voreingestelltes Standard-&quot;Ballon&quot;-Template';
+$lang['info_sysdflt_category_template'] = 'Voreingestelltes &quot;Kategorie-Listen&quot;-Template';
+$lang['info_sysdflt_dirform_template'] = 'Voreingestelltes &quot;Richtungs-Formular&quot;-Template';
+$lang['info_sysdflt_js_template'] = 'Voreingestelltes Javascript-Template';
+$lang['info_sysdflt_map_template'] = 'Voreingestelltes Karten-Template';
+$lang['info_sysdflt_sidebar_template'] = 'Voreingestelltes Seitenleisten-Template';
 $lang['info_sysdflt_template'] = 'This form provides the ability to specify the content that will be displayed when you create a new template of this type.  Editing the content in this form will have no immediate effect on your website';
 $lang['info_type_control_opt'] = 'Geben Sie an, wie das Bedienelement f&uuml;r den Kartentyp angezeigt werden soll';
 $lang['info_width'] = 'Geben Sie eine Kartenbreite an (in Pixeln)';
-$lang['infowindow_width'] = 'Breite des Info Fensters';
-$lang['infowindow_height'] = 'H&ouml;he des Info Fensters';
-$lang['info_type_controls'] = 'Benutzer erlauben, den Kartentyp zu &auml;ndern?';
-$lang['info_zoom'] = 'Geben Sie eine erste Zoomstufe (beachten Sie, dass dieser Parameter wirkungslos ist, wenn &quot;Zoom umfassen&quot;  verwendet wird)';
+$lang['infowindow_width'] = 'Breite des Info-Fensters';
+$lang['infowindow_height'] = 'H&ouml;he des Info-Fensters';
+$lang['info_type_controls'] = 'Dem Benutzer erlauben, den Kartentyp zu &auml;ndern?';
+$lang['info_zoom'] = 'Geben Sie eine erste Zoomstufe (beachten Sie, dass dieser Parameter wirkungslos ist, wenn &quot;Zoom umfassen&quot; verwendet wird)';
 $lang['info_zoom_encompass'] = 'Soll die Zoomstufe der Karte alle Punkte umfassen?';
-$lang['js_template'] = 'Javascript Template';
+$lang['js_template'] = 'Javascript-Template';
 $lang['large'] = 'Gro&szlig;';
 $lang['latitude'] = 'Breitengrad';
 $lang['latlong'] = 'Breitengrad / L&auml;ngengrad';
 $lang['location'] = 'Ort';
 $lang['longitude'] = 'L&auml;ngengrad';
 $lang['make_default'] = 'Dieses Icon als Standard-Icon festlegen';
-$lang['marker_categories'] = 'Marker Kategorien';
-$lang['marker_icons'] = 'Marker Symbole';
+$lang['marker_categories'] = 'Marker-Kategorien';
+$lang['marker_icons'] = 'Marker-Symbole';
 $lang['marker_skipped'] = 'Geolocation (adresse lat/long) fehlgeschlagen.. Marker &quot;%s&quot; &uuml;bersprungen';
 $lang['map'] = 'Karte';
 $lang['maps'] = 'Karten';
 $lang['maptemplate_addedit'] = 'Ein Karten-Template hinzuf&uuml;gen/bearbeiten';
 $lang['map_name'] = 'Kartenname';
-$lang['map_template'] = 'Mappen Template';
+$lang['map_template'] = 'Karten-Template';
 $lang['map_templates'] = 'Karten-Templates';
 $lang['map_type'] = 'Kartentyp';
 $lang['metric'] = 'Metrisch';
 $lang['moddescription'] = 'Ein einfaches Modul zum Erstellen von Google Maps';
 $lang['mouseover'] = 'MouseOver ';
-$lang['msg_addresscache_cleared'] = 'Geolocation Cache geleert';
+$lang['msg_addresscache_cleared'] = 'Geolocation-Cache geleert';
 $lang['msg_categoryadded'] = 'Kategorie hinzugef&uuml;gt';
 $lang['msg_categorydeleted'] = 'Kategorie gel&ouml;scht';
 $lang['msg_categoryupdated'] = 'Kategorie aktualisiert';
@@ -184,12 +184,12 @@ $lang['none'] = 'Keine(r)';
 $lang['panel'] = 'Feld';
 $lang['points'] = 'Punkt';
 $lang['point_combine_fudge'] = 'Geben Sie einen Radius an, welcher bestimmt welche Punkte zusammengefasst werden sollen.';
-$lang['point_combine_icon'] = 'Symbol f&uuml;r Kombinierte punkte';
+$lang['point_combine_icon'] = 'Symbol f&uuml;r kombinierte Punkte';
 $lang['point_name'] = 'Punktname';
 $lang['point_type'] = 'Punkttyp';
-$lang['policy_cachefirst'] = 'Lese-Zwischenspeicher zuerst, dann Online-Abfrage f&uuml;rAdresse';
-$lang['policy_cacheonly'] = 'Verwenden Sie immer den Zwischenspeicher';
-$lang['policy_nocache'] = 'Verwenden niemals den Zwischenspeicher (Online-Abfrage nur)';
+$lang['policy_cachefirst'] = 'Zuerst den Zwischenspeicher auslesen, dann die Online-Abfrage f&uuml;r die Adresse';
+$lang['policy_cacheonly'] = 'Immer den Zwischenspeicher verwenden';
+$lang['policy_nocache'] = 'Niemals den Zwischenspeicher verwenden (nur Online-Abfrage)';
 $lang['postinstall'] = 'Das Modul CGGoogleMaps wurde installiert.';
 $lang['postuninstall'] = 'Das Modul CGGoogleMaps und alle relevanten Daten wurden entfernt';
 $lang['preferences'] = 'Voreinstellungen';
@@ -197,13 +197,13 @@ $lang['prompt_bounds_fudge'] = 'Zoom Encompass Bounds Fudge';
 $lang['prompt_categories'] = 'Kategorien';
 $lang['prompt_directions'] = 'Richtungen';
 $lang['prompt_from_here'] = 'Von hier';
-$lang['prompt_icon_selection'] = 'Icon Auswahl';
+$lang['prompt_icon_selection'] = 'Icon-Auswahl';
 $lang['prompt_info_window'] = 'Info-Fenster anzeigen';
-$lang['prompt_info_trigger'] = 'Info-Fenster Ausl&ouml;ser anzeigen';
-$lang['prompt_lookup_policy'] = 'Lookup Regel';
+$lang['prompt_info_trigger'] = 'Info-Fenster-Ausl&ouml;ser anzeigen';
+$lang['prompt_lookup_policy'] = 'Lookup-Regel';
 $lang['prompt_lookup_service'] = 'Suchdienst';
 $lang['prompt_to_here'] = 'Hierher';
-$lang['prompt_sensor'] = 'Liefere Informationen der Geographische Lage , an die Karte';
+$lang['prompt_sensor'] = 'Informationen zur geographischen Lage in die Karte einf&uuml;gen';
 $lang['prompt_zoom'] = 'Zoomstufe';
 $lang['really_uninstall'] = 'Wollen Sie wirklich dieses Modul entfernen?';
 $lang['reset'] = 'Zur&uuml;cksetzen';
@@ -213,30 +213,29 @@ $lang['scalecontrols'] = 'Ma&szlig;stab anzeigen';
 $lang['set_dflt_map'] = 'Die Karte als Standard festlegen';
 $lang['show_category_panel'] = 'Kategorie-Feld anzeigen';
 $lang['sidebar'] = 'Sidebar anzeigen';
-$lang['sidebar_template'] = 'Seitenleisten Template';
+$lang['sidebar_template'] = 'Seitenleisten-Template';
 $lang['small'] = 'Klein';
 $lang['submit'] = 'Absenden';
-$lang['sv_controls'] = 'Streetview Steuerung anzeigen';
-$lang['sv_radius'] = 'Streetview Suchradius';
+$lang['sv_controls'] = 'Streetview-Steuerung anzeigen';
+$lang['sv_radius'] = 'Streetview-Suchradius';
 $lang['tab_advanced'] = 'Erweitert';
 $lang['tab_directions'] = 'Richtungen';
-$lang['tab_jstemplate'] = 'Javascript Template';
+$lang['tab_jstemplate'] = 'Javascript-Template';
 $lang['tab_settings'] = 'Einstellungen';
-$lang['tab_maptemplate'] = 'Karten Template';
+$lang['tab_maptemplate'] = 'Karten-Template';
 $lang['text'] = 'Text ';
 $lang['to'] = 'Nach';
 $lang['type'] = 'Typ';
 $lang['type_controls'] = 'Typenkontrolle anzeigen';
-$lang['type_control_opt'] = 'Typenkontrollen Optionen';
+$lang['type_control_opt'] = 'Typenkontroll-Optionen';
 $lang['url'] = 'URL ';
-$lang['use_category_icon'] = 'Bevorzugter Kategorie Icon';
-$lang['use_marker_icon'] = 'Bevorzugter Marker Icon';
+$lang['use_category_icon'] = 'Bevorzugter Kategorie-Icon';
+$lang['use_marker_icon'] = 'Bevorzugter Marker-Icon';
 $lang['width'] = 'Breite';
 $lang['window'] = 'Fenster';
 $lang['zoom_encompass'] = 'Zoom Encompass';
-$lang['qca'] = 'P0-1458450664-1284573084918';
-$lang['utma'] = '156861353.423163579.1322242094.1322242094.1322242094.1';
+$lang['utma'] = '156861353.963174379.1327267202.1327267202.1327269242.2';
+$lang['utmz'] = '156861353.1327267202.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1322242094.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
