@@ -102,15 +102,15 @@ $lang['help'] = '<h3>Que fait ce module ?</h3>
 <li><em>facultatif</em> - address : l&#039;adresse du lieu que vous ajoutez (vous devez mettre une adresse ou des param&egrave;tres de latitude et de longitude)</li>
 <li><em>facultatif</em> - lat : la latitude du point &agrave; ajouter</li>
 <li><em>facultatif</em> - long : la longitude du point &agrave; ajouter</li>
-<li><em>facultatif</em> - category : A comma separated list of categories for this point (there is no need for the categories to already exists)</li>
-<li><em>facultatif</em> - tooltip : A tooltip to display when hovering over a point.</li>
+<li><em>facultatif</em> - category : une liste de catr&eacute;gories de points, s&eacute;par&eacute;es par des virgules (there is no need for the categories to already exists)</li>
+<li><em>facultatif</em> - tooltip : une bulle d&#039;information &agrave; afficher quand on survole un point.</li>
 <li><em>facultatif</em> - icon : le nom de l&#039;ic&ocirc;ne &agrave; utiliser pour ce point.</li>
   </ul>
 <br/>
 <p><strong>Note :</strong> Les coordonn&eacute;es g&eacute;ographiques (latitude/longitude) ou l&#039;adresse doivent imp&eacute;rativement &ecirc;tre renseign&eacute;s.</p>
 <p><strong>Note :</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
 </ul>
-<h3>Upgrade Information:</h3>
+<h3>Informations d&#039;upgrade :</h3>
 <p><strong>Note:</strong> For people upgrading from CGGoogleMaps 1.x to the new 2.x series some work may need to be done, particularly if you have changed your map template, or are using custom options.  You may need to revise the styling of your map templates, and then update/save the values in the map settings.</p>
 <p>Also: The sidebar_html, and sidebar_class parameters have been removed from the {cggm_add_dynpoint} smarty plugin.  This is due to the category functionality that has been added.</p>
 <h3>Support</h3>
@@ -285,9 +285,9 @@ $lang['use_marker_icon'] = 'Pr&eacute;f&eacute;rer l&#039;ic&ocirc;ne du point';
 $lang['width'] = 'Largeur ';
 $lang['window'] = 'Fen&ecirc;tre';
 $lang['zoom_encompass'] = 'Entourage du zoom ';
-$lang['qca'] = 'P0-571252815-1315078016297';
-$lang['utma'] = '156861353.179240496.1322590189.1322590189.1322599553.2';
+$lang['qca'] = 'P0-1776187459-1287758187777';
+$lang['utma'] = '156861353.1232533107.1323342341.1323687908.1323704115.4';
+$lang['utmz'] = '156861353.1323342341.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1322590189.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353.1.10.1322599553';
+$lang['utmb'] = '156861353.1.10.1323704115';
 ?>
\ No newline at end of file
