@@ -142,7 +142,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
+Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p> ';
 $lang['height'] = 'Hoogte';
 $lang['help_anchor_location'] = '<strong>Opmerking:</strong> Anchor locaties specificeren de pixel locatie (in relatie tot de linkerboven hoek van de afbeelding) waar de pictogram moet komen als markeerpunt. Als er geen waarde is gegeven, wordt het midden van de pictogram gebruikt';
 $lang['help_icon_url'] = 'Benoem de URL van de ge&uuml;ploade PNG afbeelding.  Deze afbeelding mag niet groter zijn dan 32x32px, en moet transparant zijn. De URL moet vanuit de root van uw website worden benoemd';
@@ -161,10 +161,10 @@ $lang['info'] = 'Informatie';
 $lang['info_address_latlong'] = 'Opmerking: Geef <strong>OF</strong> een adres in <strong>OF</strong> een breedtegraad en lengtegraad.  Als beide zijn ingegeven, zal breedtegraad/lengtegraad worden gebruikt.';
 $lang['info_anchor_x'] = 'Infoscherm Anchor X pixel locatie';
 $lang['info_anchor_y'] = 'Infoscherm Anchor Y pixel locatie';
-$lang['info_bounds_fudge'] = 'When zoom encompass is specified you can specify a percentage <em>(in decimal)</em> by which to expand the map bounds to provide a &quot;margin&quot; around the encompassed points';
-$lang['info_category_panel'] = 'Should a panel be displayed that shows the categories of all of the map points, and allow toggling map markers on and off by category';
-$lang['info_center_lat'] = 'The Center latitude is optional.  If specified it will be used for centering the map.  Specify a value in decimal degrees i.e: -123.45';
-$lang['info_center_lon'] = 'The Center longitude is optional.  If specified it will be used for centering the map. Specify a value in decimal degrees i.e: -123.45';
+$lang['info_bounds_fudge'] = 'When zoom encompass is specified you can specify a percentage <em>(in decimal)</em> by which to expand the map bounds to provide a &quot;margin&quot; around the encompassed points ';
+$lang['info_category_panel'] = 'Should a panel be displayed that shows the categories of all of the map points, and allow toggling map markers on and off by category ';
+$lang['info_center_lat'] = 'The Center latitude is optional.  If specified it will be used for centering the map.  Specify a value in decimal degrees i.e: -123.45 ';
+$lang['info_center_lon'] = 'The Center longitude is optional.  If specified it will be used for centering the map. Specify a value in decimal degrees i.e: -123.45 ';
 $lang['info_combine_points'] = 'If selected, points that are within a specified radius of each other will be combined into one marker on the map.  This functionality is useful if multiple entries exist at the same (or almost the same) coordinates, to ease in selection.  This functionality is independant of the map zoom level.  ';
 $lang['info_controls'] = 'Moeten zoom en pan buttons worden weergegeven?';
 $lang['info_controls_size'] = 'Geef de grootte op van de buttons op de kaart';
@@ -180,13 +180,13 @@ $lang['info_infowindow_height'] = 'Geef de hoogte (in pixels) op voor het inform
 $lang['info_infowindow_width'] = 'Geef de breedte (in pixels) op voor het informatievenster';
 $lang['info_map_type'] = 'Geef het standaard kaarttype op (als de typebesturingselementen worden weergeven kan de gebruiker het type wijzigen nadat de kaart is geladen)';
 $lang['info_nav_control_opt'] = 'Geef het type van de navigatie-elementen op voor de kaart';
-$lang['info_point_combine_fudge'] = 'The smaller the radius means that fewer points will be combined into one map marker.  Negative values are invalid.';
-$lang['info_point_combine_icon'] = 'Specify an icon to use to illustrate on the map that the marker consists of multiple points that are within a small area';
-$lang['info_scalecontrols'] = 'A scale can optionally be displayed in the lower right corner of the map';
-$lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable of providing latitude and longitude information.  Do you want to enable this?';
+$lang['info_point_combine_fudge'] = 'Hoe kleiner de radius, hoe minder punten gecombineerd zullen worden in &eacute;&eacute;n map marker.  Negatieve waarden zijn niet toegestaan. ';
+$lang['info_point_combine_icon'] = 'Specify an icon to use to illustrate on the map that the marker consists of multiple points that are within a small area ';
+$lang['info_scalecontrols'] = 'A scale can optionally be displayed in the lower right corner of the map ';
+$lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable of providing latitude and longitude information.  Do you want to enable this? ';
 $lang['info_sidebar'] = 'Moet er een sidebar met alle punten op de kaart worden weergegeven?';
 $lang['info_sv_controls'] = 'Moeten StreetView buttons worden weergegeven op de kaart?';
-$lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street.';
+$lang['info_sv_radius'] = 'When Streetview is enabled for a marker, how far (in meters) should it search for a valid streetview location.  This is important in rural areas where StreetView has not necessarily gone through every street. ';
 $lang['info_sysdflt_baloon_template'] = 'Systeemstandaard &quot;Ballon&quot; sjaboon';
 $lang['info_sysdflt_category_template'] = 'Systeemstandaard &quot;Categorielijst&quot; sjabloon';
 $lang['info_sysdflt_dirform_template'] = 'Systeemstandaard &quot;Bestemmingsformulier&quot; sjabloon';
@@ -244,7 +244,7 @@ $lang['policy_nocache'] = 'Nooit de cache gebruiken (alleen online opzoeken)';
 $lang['postinstall'] = 'CGGoogleMaps is ge&iuml;nstalleerd';
 $lang['postuninstall'] = 'De CGGoogleMaps module en alle relevante bestanden zijn verwijderd';
 $lang['preferences'] = 'Eigenschappen';
-$lang['prompt_bounds_fudge'] = 'Zoom Encompass Bounds Fudge';
+$lang['prompt_bounds_fudge'] = 'Zoom Encompass Bounds Fudge ';
 $lang['prompt_categories'] = 'Categorie&euml;n';
 $lang['prompt_directions'] = 'Bestemmingen';
 $lang['prompt_from_here'] = 'Vanaf hier';
@@ -285,9 +285,9 @@ $lang['use_marker_icon'] = 'Kies een markeerpictogram';
 $lang['width'] = 'Breedte';
 $lang['window'] = 'Venster';
 $lang['zoom_encompass'] = 'Inzoom omgeving';
-$lang['utmb'] = '156861353';
-$lang['utma'] = '156861353.448615243.1322242255.1322242255.1322242255.1';
+$lang['utmz'] = '156861353.1327535062.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1501314252.1327535062.1327535062.1327535062.1';
+$lang['qca'] = 'P0-802263609-1268423862699';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1322242255.1.1.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
-$lang['qca'] = 'P0-854772080-1311691512069';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
