@@ -23,7 +23,7 @@ $lang['controls'] = 'Navig&aacute;cia';
 $lang['controls_size'] = 'Veľkosť navig&aacute;cie';
 $lang['default'] = 'Prednastaven&eacute;';
 $lang['default_icon'] = 'Prednastavenn&aacute; ikonka';
-$lang['default_templates'] = 'prednastaven&eacute; &scaron;abl&oacute;ny';
+$lang['default_templates'] = 'Prednastaven&eacute; &scaron;abl&oacute;ny';
 $lang['delete'] = 'Odstr&aacute;niť';
 $lang['delete_icon'] = 'Odstr&aacute;niť ikonku';
 $lang['delete_map'] = 'Odstr&aacute;niť mapu';
@@ -51,7 +51,7 @@ $lang['error_noapikey'] = 'Google API Key je pr&aacute;zdne';
 $lang['error_noapikey2'] = 'Tento modul vyžaduje Google Api kľuč, bez tohto kľuča bude nefunkčn&yacute;';
 $lang['error_notfound'] = 'Požadovan&aacute; položka nen&aacute;jden&aacute;';
 $lang['error_permissiondenied'] = 'Nem&aacute;te dostatočn&eacute; pr&aacute;va na vykonanie tejto akcie';
-$lang['friendlyname'] = 'Calguyov&eacute; google mapy';
+$lang['friendlyname'] = 'Google mapy';
 $lang['from'] = 'Z';
 $lang['get_directions'] = 'Z&iacute;skať s&uacute;radnice';
 $lang['google_api_key'] = 'Google API kľ&uacute;č';
@@ -148,6 +148,8 @@ $lang['help_icon_url'] = 'Specify the URL to the pre-uploaded PNG image.  This i
 $lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page.';
 $lang['help_param_map'] = 'Specify the ID or map name to use for laying out the google map.  If this parameter is not specified, the default map (if any) is used.';
 $lang['help_param_maptemplate'] = 'Specify the name of an existing, non default map template to use for this output.  If this parameter is not specified, the current default map template will be used';
+$lang['help_param_zoomlevel'] = '(integer) Allows overriding the zoom level stored with the map.  Valid values are from 1 to 17';
+$lang['help_param_zoomencompass'] = '(boolean) Allows overriding the zoom encompass setting that is stored with the map.';
 $lang['hide_directions'] = 'Skryť trasovanie';
 $lang['horizontal_bar'] = 'Horizont&aacute;lna časť';
 $lang['hybrid'] = 'Hybridna';
@@ -247,8 +249,8 @@ $lang['prompt_from_here'] = 'Z miesta';
 $lang['prompt_icon_selection'] = 'V&yacute;ber ikonky';
 $lang['prompt_info_window'] = 'Okno z inform&aacute;ciami';
 $lang['prompt_info_trigger'] = 'Udalosť vyvolania okna';
-$lang['prompt_lookup_policy'] = 'Lookup Policy';
-$lang['prompt_lookup_service'] = 'Lookup Service';
+$lang['prompt_lookup_policy'] = 'Pravidl&aacute;';
+$lang['prompt_lookup_service'] = 'Servis';
 $lang['prompt_to_here'] = 'Do miesta ';
 $lang['prompt_sensor'] = 'Supply Geographic location information to the map';
 $lang['prompt_zoom'] = 'Level zoomovanie';
@@ -260,14 +262,14 @@ $lang['scalecontrols'] = 'Zobraziť mierku';
 $lang['set_dflt_map'] = 'Nastaviť mapu ako prednastaven&uacute;';
 $lang['show_category_panel'] = 'Zobraziť panel kateg&oacute;rie';
 $lang['sidebar'] = 'Zobraziť bočn&yacute; panel';
-$lang['sidebar_template'] = '&Scaron;abl&oacute;na bočn&eacute;ho pan eli';
+$lang['sidebar_template'] = '&Scaron;abl&oacute;na bočn&eacute;ho panelu';
 $lang['small'] = 'Mal&eacute;';
 $lang['submit'] = 'Odoslať';
 $lang['sv_controls'] = 'Zobraziť ovl&aacute;dacie prvky Streetview';
 $lang['sv_radius'] = 'Vyhľad&aacute;vac&iacute; r&aacute;dius Streetview';
 $lang['tab_advanced'] = 'Roz&scaron;&iacute;ren&eacute;';
 $lang['tab_directions'] = 'Smerovanie';
-$lang['tab_jstemplate'] = '&Scaron;abl&oacute;na javascriptu ;)';
+$lang['tab_jstemplate'] = '&Scaron;abl&oacute;na javascriptu';
 $lang['tab_settings'] = 'Nastavenia';
 $lang['tab_maptemplate'] = '&Scaron;abl&oacute;na mapy';
 $lang['text'] = 'Text';
@@ -281,9 +283,9 @@ $lang['use_marker_icon'] = 'Prednastaven&aacute; ikonka značky';
 $lang['width'] = 'Dĺžka';
 $lang['window'] = 'Okno';
 $lang['zoom_encompass'] = 'Zoom Encompass';
-$lang['utmc'] = '156861353';
-$lang['utma'] = '156861353.787374649.1294590090.1297522108.1297527544.20';
-$lang['utmz'] = '156861353.1297522108.19.18.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/code/34';
-$lang['qca'] = 'P0-1084349543-1294590090923';
+$lang['utma'] = '156861353.1685542931.1302729339.1303408317.1303506677.10';
+$lang['utmz'] = '156861353.1303408317.9.8.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['qca'] = 'P0-455094516-1302813066046';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
