@@ -511,41 +511,41 @@ class cggm_map_generator
   public function get_center_lat()
   {
     $this->_calc_coords_meta();
-    return $this->_meta['center_lat'];
+    return number_format($this->_meta['center_lat'],6,'.',',');
   }
 
 
   public function get_center_lon()
   {
-    return $this->_meta['center_lon'];
+    return number_format($this->_meta['center_lon'],6,'.',',');
   }
 
 
   public function get_min_lat()
   {
     $this->_calc_coords_meta();
-    return $this->_meta['min_lat'];
+    return number_format($this->_meta['min_lat'],6,'.',',');
   }
 
 
   public function get_min_lon()
   {
     $this->_calc_coords_meta();
-    return $this->_meta['min_lon'];
+    return number_format($this->_meta['min_lon'],6,'.',',');
   }
 
 
   public function get_max_lat()
   {
     $this->_calc_coords_meta();
-    return $this->_meta['max_lat'];
+    return number_format($this->_meta['max_lat'],6,'.',',');
   }
 
 
   public function get_max_lon()
   {
     $this->_calc_coords_meta();
-    return $this->_meta['max_lon'];
+    return number_format($this->_meta['max_lon'],6,'.',',');
   }
 
 
